@@ -54,9 +54,9 @@ class __Validate(object):
                     if mongo:
                         query_dict.update(self.generate_mongo_query(p))
                     else:
-                        f, ex = self.generate_django_orm_query(p)
-                        query_dict['filter'].update(f)
-                        query_dict['exclude'].update(ex)
+                        _dict = self.generate_django_orm_query(p)
+                        query_dict['filter'].update(_dict['filter'])
+                        query_dict['exclude'].update(_dict['exclude'])
                 queries.append(query_dict)
             else:
                 queries.append(
