@@ -49,7 +49,8 @@ class CredentialMixin(object):
             return user_id
         return False
 
-    def get_credential(self, request, model, check_user=True):
+    def get_credential(self, request, model, check_user=False):
+        # check user deprecated
         user_info = self.get_user_info(request)
         user_id = user_info["id"]
         cred_id = request.GET.get("credential_id")
